module Bastion
  # Config class
  #
  #
  class Config
    USER   = "#{ENV['HOME']}/.bastion/config"
    SYSTEM = "/etc/bastion/config"
    ENVVAR = "BASTION_HOST"

    def initialize(options)
      @system = read(SYSTEM)
      @user   = read(USER)
      @env    = ENV[ENVVAR]
      @option = options[:host]
      @host   = @option || @env || @user || @system
      save @host if options[:save]
    end

    def info
      puts "System : #{@system}"
      puts "User   : #{@user}"
      puts "Env    : #{@env}"
      puts "Option : #{@option}"
      puts "Using  : #{@host}"
    end

    def read(file, default = nil)
      return default unless File.exist?(file)
      value = File.read(file)
      value.empty? ? nil : value
    end

    def save(value)
      dir = File.dirname(USER)
      Dir.mkdir(dir) unless Dir.exist?(dir)
      File.write USER, value
      File.read USER
    end

    def method_missing(name)
      instance_variable_get :"@#{name}"
    end
  end
end
